@@ -1,5 +1,5 @@
 ; libctl: flexible Guile-based control files for scientific software
-; Copyright (C) 1998-2019 Massachusetts Institute of Technology and Steven G. Johnson
+; Copyright (C) 1998-2020 Massachusetts Institute of Technology and Steven G. Johnson
 ;
 ; This library is free software; you can redistribute it and/or
 ; modify it under the terms of the GNU Lesser General Public
@@ -92,17 +92,17 @@
 
 ; some notes regarding prisms:
 ;  (a) When instantiating a prism, typically only the
-;      fields `vertices`, `height,` and (optionally) `axis`
-;      will be initialized by the user; all remaining fields are
-;      derived properties that are computed internally. (So, morally
-;      they should be thought of as having been declared using 
-;      `define-derived-property` or `define-post-processed-property,`
-;      except here the code that does the derivation or
-;      post-processing is implemented in C, not scheme.)
+;      fields `vertices`, `height,` (optionally) `axis`,
+;      and `sidewall_angle` will be initialized by the user; all
+;      remaining fields are derived properties that are computed
+;      internally. (So, morally, they should be thought of as having
+;      been declared using `define-derived-property` or
+;      `define-post-processed-property,` except here the code that does
+;      the derivation or post-processing is implemented in C, not scheme.)
 ;  (b) The suffix _p (for "prism") is used to identify variables
 ;      that store coordinates of points or components of vectors
-;      in the prism coordinate system. (The prism coordinate system 
-;      is defined by the condition that the prism axis is the z-axis 
+;      in the prism coordinate system. (The prism coordinate system
+;      is defined by the condition that the prism axis is the z-axis
 ;      and the prism floor lies in the xy plane at z==0.) Variables
 ;      with no suffix refer to quantities in ordinary 3D space.
 ;  (c) "centroid" refers to the centroid of the prism floor polygon; this is
@@ -117,13 +117,23 @@
 ;      (center = centroid + 0.5*height*axis), so---in contrast to all other
 ;      types of geometric-object---there is no need to specify the `center`
 ;      field when instantiating a prism.
+;  (f) The sidwall angle determines an angle at which the prism is extruded.
+;      A positive sidewall angle determines a prism that extrudes inward at
+;      the given angle, and a negative sidewall angle determines a prisms
+;      that extrudes outward. This is useful for modeling a prism formed in
+;      a foundry that cannot grow objects with a perfectly normal sidewall.
 (define-class prism geometric-object
 ; fields to be filled in by users
   (define-property vertices '() (make-list-type 'vector3))
   (define-property height 0 'number)
   (define-property axis (vector3 0 0 0) 'vector3)
+  (define-property sidewall_angle 0 'number)
 ; derived fields computed internally
   (define-property vertices_p '() (make-list-type 'vector3))
+  (define-property top_polygon_diff_vectors_p '() (make-list-type 'vector3))
+  (define-property top_polygon_diff_vectors_scaled_p '() (make-list-type 'vector3))
+  (define-property vertices_top_p '() (make-list-type 'vector3))
+  (define-property vertices_top '() (make-list-type 'vector3))
   (define-property centroid (vector3 0 0 0) 'vector3)
   (define-property workspace '() (make-list-type 'number))
   (define-property m_c2p identity_matrix 'matrix3x3)
